==> haskell-dataenc-0.14.0.7-8-i686.pkg.tar.xz: usr/share/haskell/register/haskell-dataenc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: dataenc
version: 0.14.0.7
id: dataenc-0.14.0.7-G2dHH1qsNfRHkR4LBnLkUl
key: dataenc-0.14.0.7-G2dHH1qsNfRHkR4LBnLkUl
license: BSD3
copyright: Magnus Therning, 2007-2012, Gracjan Polak, 2014
maintainer: Gracjan Polak <gracjanpolak@gmail.com>
homepage: http://www.haskell.org/haskellwiki/Library/Data_encoding
synopsis: Data encoding library
description:
    Data encoding library currently providing Base16, Base32,
    Base32Hex, Base64, Base64Url, Base85, Python string escaping,
    Quoted-Printable, URL encoding, uuencode, xxencode, and yEncoding.
category: Codec
author: Magnus Therning
exposed: True
exposed-modules:
    Codec.Binary.Base16 Codec.Binary.Base32 Codec.Binary.Base32Hex
    Codec.Binary.Base64 Codec.Binary.Base64Url Codec.Binary.Base85
    Codec.Binary.DataEncoding Codec.Binary.PythonString
    Codec.Binary.QuotedPrintable Codec.Binary.Url Codec.Binary.Uu
    Codec.Binary.Xx Codec.Binary.Yenc
hidden-modules: Codec.Binary.Util
abi: d63db7a014fcb52d006147904e614b1f
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/dataenc-0.14.0.7
library-dirs: /usr/lib/ghc-8.0.1/site-local/dataenc-0.14.0.7
data-dir: /usr/share/i386-linux-ghc-8.0.1/dataenc-0.14.0.7
hs-libraries: HSdataenc-0.14.0.7-G2dHH1qsNfRHkR4LBnLkUl
depends:
    array-0.5.1.1 base-4.9.0.0 containers-0.5.7.1
haddock-interfaces: /usr/share/doc/haskell-dataenc/html/dataenc.haddock
haddock-html: /usr/share/doc/haskell-dataenc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dataenc-0.14.0.7-9-i686.pkg.tar.xz: usr/share/haskell/register/haskell-dataenc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: dataenc
version: 0.14.0.7
id: dataenc-0.14.0.7-4kYmvTK9qwJAAgNTcfssx3
key: dataenc-0.14.0.7-4kYmvTK9qwJAAgNTcfssx3
license: BSD3
copyright: Magnus Therning, 2007-2012, Gracjan Polak, 2014
maintainer: Gracjan Polak <gracjanpolak@gmail.com>
homepage: http://www.haskell.org/haskellwiki/Library/Data_encoding
synopsis: Data encoding library
description:
    Data encoding library currently providing Base16, Base32,
    Base32Hex, Base64, Base64Url, Base85, Python string escaping,
    Quoted-Printable, URL encoding, uuencode, xxencode, and yEncoding.
category: Codec
author: Magnus Therning
exposed: True
exposed-modules:
    Codec.Binary.Base16 Codec.Binary.Base32 Codec.Binary.Base32Hex
    Codec.Binary.Base64 Codec.Binary.Base64Url Codec.Binary.Base85
    Codec.Binary.DataEncoding Codec.Binary.PythonString
    Codec.Binary.QuotedPrintable Codec.Binary.Url Codec.Binary.Uu
    Codec.Binary.Xx Codec.Binary.Yenc
hidden-modules: Codec.Binary.Util
abi: ee20959876dd00f76cce9d6440c0d0fa
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/dataenc-0.14.0.7
library-dirs: /usr/lib/ghc-8.0.2/site-local/dataenc-0.14.0.7
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/dataenc-0.14.0.7
hs-libraries: HSdataenc-0.14.0.7-4kYmvTK9qwJAAgNTcfssx3
depends:
    array-0.5.1.1 base-4.9.1.0 containers-0.5.7.1
haddock-interfaces: /usr/share/doc/haskell-dataenc/html/dataenc.haddock
haddock-html: /usr/share/doc/haskell-dataenc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
